==> cms-db_v0.9.tar.gz: admin/firstrun.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('firstrun');
include('locale.inc.php');
$locale = new LocalizingClass('firstrun');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<style type="text/css">
		/* <![CDATA[ */
		#license {
			background: #f4f4f4;
			border: 1px solid #ddd;
			/*max-width: 60em;*/
			padding: .5em;
		}
		#license p {
			margin: .5em 0;
		}
		/* ]]> */
		</style>
	</head>
	<body>

	<h1><?php locale('title') ?></h1>
	<p>
		<?php printf(locale('desc_license',true), 'gnu-gpl.php', 'http://www.gnu.org/licenses/gpl.html') ?>
	</p>
	<div id="license">
		<p>
			<?php locale('licensenotes1') ?>
		</p>
		<p>
			<?php locale('licensenotes2') ?>
		</p>
		<p>
			<?php locale('licensenotes3') ?>
		</p>
	</div>
	<p>
		<?php printf(locale('desc_clickbutton',true), locale('link_next',true)) ?>
	</p>
	<form method="post" action="firstrun1.php?<?php echo SID; csrf_protection_get_html() ?>">
		<p>
			<input type="submit" value="<?php locale_escape('link_next', '"') ?>" />
		</p>
	</form>

	</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/firstrun.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('firstrun');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('firstrun');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<style type="text/css">
		/* <![CDATA[ */
		#license {
			background: #f4f4f4;
			border: 1px solid #ddd;
			/*max-width: 60em;*/
			padding: .5em;
		}
		#license p {
			margin: .5em 0;
		}
		/* ]]> */
		</style>
	</head>
	<body>

	<h1><?php locale('title') ?></h1>
	<p>
		<?php printf(locale('desc_license',true), 'gnu-gpl.php', 'http://www.gnu.org/licenses/gpl.html') ?>
	</p>
	<div id="license">
		<p>
			<?php locale('licensenotes1') ?>
		</p>
		<p>
			<?php locale('licensenotes2') ?>
		</p>
		<p>
			<?php locale('licensenotes3') ?>
		</p>
	</div>
	<p>
		<?php printf(locale('desc_clickbutton',true), locale('link_next',true)) ?>
	</p>
	<form method="post" action="firstrun1.php?<?php echo SID; csrf_protection_get_html() ?>">
		<p>
			<input type="submit" value="<?php locale_escape('link_next', '"') ?>" />
		</p>
	</form>

	</body>
</html>
